<?php
/**
 * Shows the `working-hours` form field on listing forms.
 *
 * @author      pebas
 * @package     Lisner
 * @category    Template
 * @version     1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$classes    = array( 'input-text' );
$field_name = isset( $field['name'] ) ? $field['name'] : $key;

$days    = array(
	'monday'    => esc_html__( 'Mon', 'lisner-core' ),
	'tuesday'   => esc_html__( 'Tue', 'lisner-core' ),
	'wednesday' => esc_html__( 'Wed', 'lisner-core' ),
	'thursday'  => esc_html__( 'Thu', 'lisner-core' ),
	'friday'    => esc_html__( 'Fri', 'lisner-core' ),
	'saturday'  => esc_html__( 'Sat', 'lisner-core' ),
	'sunday'    => esc_html__( 'Sun', 'lisner-core' )
);
$post_id = isset( $_REQUEST['job_id'] ) ? $_REQUEST['job_id'] : '';
?>
<div class="working-hours">
	<div class="working-hours-days">
		<?php if ( ! empty( $days ) ) : ?>
			<div class="working-hours-days-wrapper">
				<?php foreach ( $days as $day => $day_title ) : ?>
					<!-- Working Days Labels -->
					<div class="working-hours-day working-hours-day-<?php echo esc_attr( $day ); ?>">
						<a href="javascript:"
						   class="<?php echo $day == 'monday' ? esc_attr( 'active' ) : ''; ?>"
						   data-working-day="<?php echo esc_attr( $day ); ?>"><?php echo esc_html( $day_title ); ?></a>
					</div>
				<?php endforeach; ?>
			</div>
			<div class="working-hours-form-wrapper">
				<?php foreach ( $days as $day => $day_title ) : ?>
					<?php $working_radio_hours_open = get_post_meta( $post_id, "_listing_{$day}_hours_open", false ); ?>
					<?php $working_radio_hours_closed = get_post_meta( $post_id, "_listing_{$day}_hours_close", false ); ?>
					<?php $working_hours = ! empty( $working_radio_hours_open ) && ! empty( $working_radio_hours_closed ) ? array_combine( array_shift( $working_radio_hours_open ), array_shift( $working_radio_hours_closed ) ) : ''; ?>

					<?php $count_count = rand(); ?>

					<?php $working_radio_value = get_post_meta( $post_id, "_listing_{$day}_hours_radio", true ); ?>
					<?php $working_radio_value = isset( $working_radio_value ) ? $working_radio_value : 'custom'; ?>
					<!-- Working Days Form -->
					<div class="working-days-form working-days-form-<?php echo esc_attr( $day ); ?> <?php echo $day != 'monday' ? esc_attr( 'hidden' ) : ''; ?>">
						<div class="working-hours-day-options working-hours-day-options-<?php echo esc_attr( $day ); ?>">
							<div class="custom-control custom-radio">
								<input type="radio"
								       id="working-hours-radio-custom-<?php echo esc_attr( $day ); ?>"
								       class="custom-control-input working-hours-radio <?php echo esc_attr( 'radio-' . $day ); ?>"
								       name="<?php echo esc_attr( "_listing_{$day}_hours_radio" ); ?>"
								       data-working-radio="<?php echo esc_attr( $day ); ?>"
								       value="custom" <?php echo $working_radio_value == 'custom' ? esc_attr( 'checked' ) : ( ! in_array( $working_radio_value, array(
									'open',
									'closed',
									'appointment'
								) ) ? esc_attr( 'checked' ) : '' ); ?> />
								<label for="working-hours-radio-custom-<?php echo esc_attr( $day ); ?>"
								       class="custom-control-label"><?php esc_html_e( 'Enter Times', 'lisner-core' ); ?></label>
							</div>
							<div class="custom-control custom-radio">
								<input type="radio"
								       id="working-hours-radio-open-<?php echo esc_attr( $day ); ?>"
								       data-working-radio="<?php echo esc_attr( $day ); ?>"
								       class="custom-control-input working-hours-radio <?php echo esc_attr( 'radio-' . $day ); ?>"
								       name="<?php echo esc_attr( "_listing_{$day}_hours_radio" ); ?>"
								       value="open" <?php echo $working_radio_value == 'open' ? esc_attr( 'checked' ) : ''; ?> />
								<label for="working-hours-radio-open-<?php echo esc_attr( $day ); ?>"
								       class="custom-control-label"><?php esc_html_e( 'Open All Day', 'lisner-core' ); ?></label>
							</div>
							<div class="custom-control custom-radio">
								<input type="radio"
								       id="working-hours-radio-closed-<?php echo esc_attr( $day ); ?>"
								       data-working-radio="<?php echo esc_attr( $day ); ?>"
								       class="custom-control-input working-hours-radio <?php echo esc_attr( 'radio-' . $day ); ?>"
								       name="<?php echo esc_attr( "_listing_{$day}_hours_radio" ); ?>"
								       value="closed" <?php echo $working_radio_value == 'closed' ? esc_attr( 'checked' ) : ''; ?> />
								<label for="working-hours-radio-closed-<?php echo esc_attr( $day ); ?>"
								       class="custom-control-label"><?php esc_html_e( 'Closed All Day', 'lisner-core' ); ?></label>
							</div>
							<div class="custom-control custom-radio">
								<input type="radio"
								       id="working-hours-radio-appointment-<?php echo esc_attr( $day ); ?>"
								       data-working-radio="<?php echo esc_attr( $day ); ?>"
								       class="custom-control-input working-hours-radio <?php echo esc_attr( 'radio-' . $day ); ?>"
								       name="<?php echo esc_attr( "_listing_{$day}_hours_radio" ); ?>"
								       value="appointment" <?php echo $working_radio_value == 'appointment' ? esc_attr( 'checked' ) : ''; ?> />
								<label for="working-hours-radio-appointment-<?php echo esc_attr( $day ); ?>"
								       class="custom-control-label"><?php esc_html_e( 'By Appointment Only', 'lisner-core' ); ?></label>
							</div>
						</div>

						<div class="working-hours-day-time working-hours-day-time-<?php echo esc_attr( $day ); ?>">
							<div class="working-hours-labels">
								<span class="working-hours-label"><?php esc_html_e( 'Time From', 'lisner-core' ); ?></span>
								<span class="working-hours-label"><?php esc_html_e( 'Time To', 'lisner-core' ); ?></span>
							</div>
							<?php if ( empty( $working_hours ) ) : ?>
								<!-- Working hours template / Open -->
								<div class="working-hours-template working-hours-template-<?php echo esc_attr( $day ); ?> working-hours-template-active">
									<div class="working-hours-fields">
                                <span class="working-hours-input working-hours-input-open input-group">
                                    <input type="text"
                                           class="timepicker form-control"
                                           autocomplete="off"
                                           readonly
                                           placeholder="<?php echo esc_attr( '00:00' ); ?>"
                                           name="<?php echo esc_attr( "_listing_{$day}_hours_open[{#}]" ); ?>">
                                </span>
										<span class="working-hours-input working-hours-input-close input-group">
                                    <input type="text"
                                           class="timepicker form-control"
                                           autocomplete="off"
                                           readonly
                                           placeholder="<?php echo esc_attr( '00:00' ); ?>"
                                           name="<?php echo esc_attr( "_listing_{$day}_hours_close[{#}]" ); ?>">
                                </span>

										<!-- Add working hour -->
										<a href="javascript:" data-hours-add="<?php echo esc_attr( $day ); ?>"
										   class="working-hours-add"><i
													class="material-icons"><?php echo esc_attr( 'add_circle_outline' ); ?></i><?php esc_html_e( 'Add Hours', 'lisner-core' ); ?>
										</a>
									</div>
								</div>
								<!-- !Working hours template / Open -->
							<?php endif; ?>

							<!-- Working hours template / Hidden -->
							<div class="working-hours-template working-hours-template-<?php echo esc_attr( $day ); ?> hidden">
								<div class="working-hours-fields">
                                <span class="working-hours-input working-hours-input-open input-group">
                                    <input type="text"
                                           class="timepicker form-control"
                                           autocomplete="off"
                                           readonly
                                           placeholder="<?php echo esc_attr( '00:00' ); ?>"
                                           name="<?php echo esc_attr( "_listing_{$day}_hours_open[{#}]" ); ?>" disabled>
                                </span>
									<span class="working-hours-input working-hours-input-close input-group">
                                    <input type="text"
                                           class="timepicker form-control"
                                           autocomplete="off"
                                           readonly
                                           placeholder="<?php echo esc_attr( '00:00' ); ?>"
                                           name="<?php echo esc_attr( "_listing_{$day}_hours_close[{#}]" ); ?>"
                                           disabled>
                                </span>

									<!-- Remove Working Hour-->
									<a href="javascript:" class="working-hours-remove"><i
												class="material-icons"><?php echo esc_html( 'delete' ); ?></i></a>
								</div>
							</div>
							<!-- !Working hours template -->

							<?php $count_count ++; ?>

							<?php $count = 0; ?>
							<?php if ( ! empty( $working_hours ) ) : ?>
								<?php foreach ( $working_hours as $open => $close ): ?>
									<?php if ( ! empty( $open ) && ! empty( $close ) ) : ?>
										<!-- Working hours default -->
										<div class="working-hours-template working-hours-template-<?php echo esc_attr( $day ); ?>">
											<div class="working-hours-fields">
                                            <span class="working-hours-input working-hours-input-open input-group">
                                                <label for="working-hours-time-<?php echo esc_attr( $day . $count ); ?>"></label>
                                                <input type="text"
                                                       class="timepicker form-control"
                                                       name="<?php echo esc_attr( "_listing_{$day}_hours_open[{$count}]" ); ?>"
                                                       autocomplete="off"
                                                       readonly
                                                       value="<?php echo ! empty( $open ) ? esc_attr( $open ) : ''; ?>" />
                                            </span>
												<span class="working-hours-input working-hours-input-close input-group">
                                                <label for="working-hours-time-<?php echo esc_attr( $day . $count ); ?>"></label>
                                                <input type="text"
                                                       class="timepicker form-control"
                                                       name="<?php echo esc_attr( "_listing_{$day}_hours_close[{$count}]" ); ?>"
                                                       autocomplete="off"
                                                       readonly
                                                       value="<?php echo ! empty( $close ) ? esc_attr( $close ) : ''; ?>" />
                                            </span>

												<?php if ( ! empty( $working_hours ) && 0 == $count ) : ?>
													<!-- Add working hour -->
													<a href="javascript:"
													   data-hours-add="<?php echo esc_attr( $day ); ?>"
													   class="working-hours-add"><i
																class="material-icons"><?php echo esc_attr( 'add_circle_outline' ); ?></i><?php esc_html_e( 'Add Hours', 'lisner-core' ); ?>
													</a>
												<?php else: ?>
													<a href="javascript:" class="working-hours-remove"><i
																class="material-icons"><?php echo esc_html( 'delete' ); ?></i></a>
												<?php endif; ?>
											</div>
										</div>
										<?php $count ++; ?>
									<?php endif; ?>
								<?php endforeach; ?>
							<?php endif; ?>
							<!-- !Working hours default -->
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		<?php endif; ?>
	</div>
</div>